@@ -221,7 +221,7 @@ void IPlot::leaveEvent(QEvent* /*e*/) {
   update();
 }
 
-void IPlot::enterEvent(QEvent* /*e*/) {
+void IPlot::enterEvent(QEnterEvent* /*e*/) {
   needsRedraw = true;
   QCursor cursor = QCursor(QPixmap(":/cursors/cursorArrow.png"), 0, 0);
   CCanvas::setOverrideCursor(cursor, "IPlot::enterEvent");
@@ -281,7 +281,7 @@ void IPlot::mouseMoveEvent(QMouseEvent* e) {
 
   if (mouseDidMove) {
     if (!scrOptRange.isNull()) {
-      delete scrOptRange;
+      scrOptRange->deleteLater();
     }
     QPoint diff = pos - posLast;
 
@@ -422,7 +422,6 @@ bool IPlot::mouseReleaseEventNormal(QMouseEvent* e) {
           As the screen option is created on the fly it has to be connected to all slots,too.
           Later, when destroyed the slots will be disconnected automatically.
        */
-      delete scrOptRange;
       scrOptRange = new CScrOptRangeTrk(pos, trk, nullptr, this);
       connect(scrOptRange->toolHidePoints, &QToolButton::clicked, this, &IPlot::slotHidePoints);
       connect(scrOptRange->toolShowPoints, &QToolButton::clicked, this, &IPlot::slotShowPoints);
@@ -457,7 +456,9 @@ bool IPlot::mouseReleaseEventNormal(QMouseEvent* e) {
 
     case eMouseClick2nd: {
       // In second click state a mouse click will reset the range selection
-      delete scrOptRange;
+      if (!scrOptRange.isNull()) {
+        scrOptRange->deleteLater();
+      }
       trk->setMode(CGisItemTrk::eModeNormal, objectName());
       idxSel1 = idxSel2 = NOIDX;
       mouseClickState = eMouseClickIdle;
@@ -1007,7 +1008,7 @@ void IPlot::drawDecoration(QPainter& p) {
 
       // check if the mouse is near a waypoint
       if (!showWptLabels) {
-        for (const CPlotData::point_t& tag : qAsConst(data->tags)) {
+        for (const CPlotData::point_t& tag : std::as_const(data->tags)) {
           int ptx = left + data->x().val2pt(tag.point.x());
 
           if (qAbs(x - ptx) >= 10) {
@@ -1085,7 +1086,7 @@ void IPlot::drawTags(QPainter& p) {
   CPlotAxis& xaxis = data->x();
   CPlotAxis& yaxis = data->y();
 
-  for (const CPlotData::point_t& tag : qAsConst(data->tags)) {
+  for (const CPlotData::point_t& tag : std::as_const(data->tags)) {
     int ptx = left + xaxis.val2pt(tag.point.x());
     int pty = bottom - yaxis.val2pt(tag.point.y());
 
@@ -1130,7 +1131,7 @@ void IPlot::drawTagLabels(QPainter& p) {
 
   CPlotAxis& xaxis = data->x();
 
-  for (const CPlotData::point_t& tag : qAsConst(data->tags)) {
+  for (const CPlotData::point_t& tag : std::as_const(data->tags)) {
     int ptx = left + xaxis.val2pt(tag.point.x());
 
     if (!((left < ptx) && (ptx < right))) {
@@ -1183,8 +1184,8 @@ void IPlot::drawActivities(QPainter& p) {
     const CTrackData::trkpt_t* trkptEnd = trkData.getTrkPtByTotalIndex(range.idxTotalEnd);
 
     if (data->axisType == CPlotData::eAxisTime) {
-      x1 = data->x().val2pt(trkptBeg->time.toTime_t());
-      x2 = data->x().val2pt(trkptEnd->time.toTime_t());
+      x1 = data->x().val2pt(trkptBeg->time.toSecsSinceEpoch());
+      x2 = data->x().val2pt(trkptEnd->time.toSecsSinceEpoch());
     } else {
       x1 = data->x().val2pt(trkptBeg->distance);
       x2 = data->x().val2pt(trkptEnd->distance);
@@ -1306,7 +1307,9 @@ void IPlot::slotCopy() {
 }
 
 void IPlot::slotStopRange() {
-  scrOptRange->deleteLater();
+  if (!scrOptRange.isNull()) {
+    scrOptRange->deleteLater();
+  }
   trk->setMode(CGisItemTrk::eModeNormal, objectName());
   idxSel1 = idxSel2 = NOIDX;
   mouseClickState = eMouseClickIdle;
