@@ -21,17 +21,16 @@
 
 #include "IUnit.h"
 
-class CUnitMetric : public IUnit
-{
-public:
-    CUnitMetric(QObject* parent);
-    virtual ~CUnitMetric() = default;
+class CUnitMetric : public IUnit {
+ public:
+  CUnitMetric(QObject* parent);
+  virtual ~CUnitMetric() = default;
 
-    void meter2elevation(qreal meter, QString& val, QString& unit) const override;
-    void meter2distance(qreal meter, QString& val, QString& unit) const override;
-    void meter2speed(qreal meter, QString& val, QString& unit) const override;
-    void meter2area(qreal meter, QString& val, QString& unit) const override;
-    qreal elevation2meter(const QString& val) const override;
-    void meter2unit(qreal meter, qreal& scale, QString& unit) const override;
+  void meter2elevation(qreal meter, QString& val, QString& unit) const override;
+  void meter2distance(qreal meter, QString& val, QString& unit) const override;
+  void meter2speed(qreal meter, QString& val, QString& unit) const override;
+  void meter2area(qreal meter, QString& val, QString& unit) const override;
+  qreal elevation2meter(const QString& val) const override;
+  void meter2unit(qreal meter, qreal& scale, QString& unit) const override;
 };
-#endif // CUNITMETRIC_H
+#endif  // CUNITMETRIC_H
